@@ -13,6 +13,7 @@ mod use_mount;
 mod use_previous;
 mod use_queue;
 mod use_raf;
+mod use_raf_state;
 mod use_session_storage;
 mod use_set;
 mod use_timeout;
@@ -36,6 +37,7 @@ pub use use_mount::*;
 pub use use_previous::*;
 pub use use_queue::*;
 pub use use_raf::*;
+pub use use_raf_state::*;
 pub use use_session_storage::*;
 pub use use_set::*;
 pub use use_timeout::*;
